@@ -37,7 +37,7 @@ class OrderFilledMessage(BaseEventMessage):
     limit_price: Optional[float]
 
 
-class TradeMessage(BaseEventMessage):
+class WebsocketTradeMessage(BaseEventMessage):
     exchange: str
     order_id: str
     transaction_id: str
